@@ -1,5 +1,6 @@
 mod common;
 
+#[cfg(feature = "osrs")]
 mod osrs {
     use super::common;
 
@@ -78,6 +79,7 @@ mod osrs {
     }
 }
 
+#[cfg(feature = "rs3")]
 mod rs3 {
     use super::common;
 
